==> wodby-8.x-1.4.tar.gz: wodby/src/WodbyClientServiceInterface.php <==
<?php

namespace Drupal\wodby;

use GuzzleHttp\ClientInterface;
use Wodby\Api\Client\ApplicationApi;
use Wodby\Api\Client\BackupApi;
use Wodby\Api\Client\DomainApi;
use Wodby\Api\Client\GitRepositoryApi;
use Wodby\Api\Client\InstanceApi;
use Wodby\Api\Client\OrganizationApi;
use Wodby\Api\Client\ServerApi;
use Wodby\Api\Client\StackApi;
use Wodby\Api\Client\TaskApi;
use Wodby\Api\Client\UserApi;
use Wodby\Api\Configuration;

/**
 * Interface WodblyClientServiceInterface.
 */
interface WodbyClientServiceInterface {

  /**
   * @return \Wodby\Api\Configuration   */
  public function getWodbyConfigFromEnv(): Configuration;

  /**
   * @param string $api_key
   *
   * @return \Wodby\Api\Configuration   */
  public function getWodbyConfig(string $api_key): Configuration;

  /**
   * @param \Wodby\Api\Configuration         $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   *
   * @return \Wodby\Api\Client\ApplicationApi
   */
  public function getAppApi(Configuration $conf = NULL, ClientInterface $client = NULL): ApplicationApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\BackupApi
   */
  public function getBackupApi(Configuration $conf = NULL, ClientInterface $client = NULL): BackupApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\DomainApi
   */
  public function getDomainApi(Configuration $conf = NULL, ClientInterface $client = NULL): DomainApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\GitRepositoryApi
   */
  public function getGitRepoApi(Configuration $conf = NULL, ClientInterface $client = NULL): GitRepositoryApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\InstanceApi
   */
  public function getInstanceApi(Configuration $conf = NULL, ClientInterface $client = NULL): InstanceApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\OrganizationApi
   */
  public function getOrgApi(Configuration $conf = NULL, ClientInterface $client = NULL): OrganizationApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\ServerApi
   */
  public function getServerApi(Configuration $conf = NULL, ClientInterface $client = NULL): ServerApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\StackApi
   */
  public function getStackApi(Configuration $conf = NULL, ClientInterface $client = NULL): StackApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\TaskApi
   */
  public function getTaskApi(Configuration $conf = NULL, ClientInterface $client = NULL): TaskApi;

  /**
   * @param \Wodby\Api\Configuration    $conf
   *
   * @param \GuzzleHttp\ClientInterface $client
   * @return \Wodby\Api\Client\UserApi
   */
  public function getUserApi(Configuration $conf = NULL, ClientInterface $client = NULL): UserApi;

  /**
   * @return null|string
   */
  public function getSiteAppUuid(): ?string;

  /**
   * Stores in the config the App UUID.
   *
   * @param string $uuid
   */
  public function setSiteAppUuid(string $uuid);

  /**
   * Gets a list of Instance UUIDs to use for quick deploy.
   *
   * @return string[]
   */
  public function getQuickDeployList(): array;
}

==> wodby-8.x-1.7.tar.gz: wodby/src/WodbyClientServiceInterface.php <==
<?php

namespace Drupal\wodby;

use GuzzleHttp\ClientInterface;
use Wodby\Api\Client\ApplicationApi;
use Wodby\Api\Client\BackupApi;
use Wodby\Api\Client\DomainApi;
use Wodby\Api\Client\GitRepositoryApi;
use Wodby\Api\Client\InstanceApi;
use Wodby\Api\Client\OrganizationApi;
use Wodby\Api\Client\ServerApi;
use Wodby\Api\Client\StackApi;
use Wodby\Api\Client\TaskApi;
use Wodby\Api\Client\UserApi;
use Wodby\Api\Configuration;

/**
 * Interface WodblyClientServiceInterface.
 */
interface WodbyClientServiceInterface {

  /**
   * Gets the Wodby Configuration.
   *
   * @return \Wodby\Api\Configuration
   *   The configuration.
   */
  public function getWodbyConfigFromEnv(): Configuration;

  /**
   * Gets the Wodby Configuration.
   *
   * @param string $api_key
   *   The api key.
   *
   * @return \Wodby\Api\Configuration
   *   The configuration.
   */
  public function getWodbyConfig(string $api_key): Configuration;

  /**
   * Gets the ApplicationApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\ApplicationApi
   *   A new ApplicationApi.
   */
  public function getAppApi(Configuration $conf = NULL, ClientInterface $client = NULL): ApplicationApi;

  /**
   * Gets the BackupApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\BackupApi
   *   A new BackupApi.
   */
  public function getBackupApi(Configuration $conf = NULL, ClientInterface $client = NULL): BackupApi;

  /**
   * Gets the DomainApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\DomainApi
   *   A new DomainApi.
   */
  public function getDomainApi(Configuration $conf = NULL, ClientInterface $client = NULL): DomainApi;

  /**
   * Gets the GitRepositoryApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\GitRepositoryApi
   *   A new GitRepositoryApi.
   */
  public function getGitRepoApi(Configuration $conf = NULL, ClientInterface $client = NULL): GitRepositoryApi;

  /**
   * Gets the InstanceApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\InstanceApi
   *   A new InstanceApi.
   */
  public function getInstanceApi(Configuration $conf = NULL, ClientInterface $client = NULL): InstanceApi;

  /**
   * Gets the OrganizationApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\OrganizationApi
   *   A new OrganizationApi.
   */
  public function getOrgApi(Configuration $conf = NULL, ClientInterface $client = NULL): OrganizationApi;

  /**
   * Gets the ServerApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\ServerApi
   *   A new ServerApi.
   */
  public function getServerApi(Configuration $conf = NULL, ClientInterface $client = NULL): ServerApi;

  /**
   * Gets the StackApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\StackApi
   *   A new StackApi.
   */
  public function getStackApi(Configuration $conf = NULL, ClientInterface $client = NULL): StackApi;

  /**
   * Gets the TaskApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\TaskApi
   *   A new TaskApi.
   */
  public function getTaskApi(Configuration $conf = NULL, ClientInterface $client = NULL): TaskApi;

  /**
   * Gets the UserApi.
   *
   * @param \Wodby\Api\Configuration $conf
   *   The configuration, set as null.
   * @param \GuzzleHttp\ClientInterface $client
   *   The client, set as null.
   *
   * @return \Wodby\Api\Client\UserApi
   *   A new UserApi.
   */
  public function getUserApi(Configuration $conf = NULL, ClientInterface $client = NULL): UserApi;

  /**
   * Gets the App UUID.
   *
   * @return null|string
   *   Returns the UUID, if it exists.
   */
  public function getSiteAppUuid(): ?string;

  /**
   * Stores in the config the App UUID.
   *
   * @param string $uuid
   *   The uuid.
   */
  public function setSiteAppUuid(string $uuid);

  /**
   * Gets a list of Instance UUIDs to use for quick deploy.
   *
   * @return string[]
   *   An array of strings.
   */
  public function getQuickDeployList(): array;

}
